==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sh/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "IP grupa adresa $1 je obrisana.");
regGS("IP Group $1 added for user $2", "IP grupa $1 dodata za korisnika $2");
regGS("User permissions for $1 changed", "Korisnička prava za $1 su promenjena");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Rubrika $1 obrisana. (Izdanje: $2, publikacija: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Rubrika $1 dodata. (Izdanje: $2, publikacija: $3)");
regGS("Issue $1 changed status to $2", "Izdanju $1 promenjen status u $2 ");
regGS("User type $1 deleted", "Tip korisnika $1 je obrisan");
regGS("User type $1 added", "Tip korisnika $1 je dodat");
regGS("Topic $1 added to article", "Tema $1 je dodata članku");
regGS("Last", "Poslednji");
regGS("First", "Prvi");
regGS("Changed image properties of $1", "Promeni osobine slike $1");
regGS("Article topic $1 deleted", "Tema članka $1 je obrisana");
regGS("Article #$1 \"$2\" ($3) created.", "Članak #$1 \"$2\" ($3) je kreiran.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Članak #$1 \"$2\" ($3) je preveden u \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Članak #$1 \"$2\" ($3) je prekopiran u #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Status članka #$1: \"$2\" je promenjen iz $3 to $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Čalanak #$1: \"$2\" ($3) je obrisan.");
regGS("Text", "Tekst");
regGS("Article body", "Složen tekst");
regGS("The default subscription time for $1 has been added.", "Novi period pretplate za $1 dodat.");
regGS("Image $1 linked to article $2", "Slika $1 je povezana sa člankom $2");
regGS("Image $1 unlinked from $2", "Veza slike $1 je uklonjena sa $2");
regGS("The image $1 has been added.", "Slika $1 je dodata");
regGS("Image $1 deleted", "Slika $1 je obrisana");
regGS("Publication $1 changed", "Publikacija $1 promenjena");
regGS("Publication $1 deleted", "Publikacija $1 je obrisana");
regGS("Publication $1 added", "Publikacija $1 je dodata");
regGS("Issue $1 from publication $2 deleted", "Izdanje $1 iz publikacije $2 je obrisano");
regGS("Issue $1 added in publication $2", "Izdanje $1 dodato u publikaciju $2");
regGS("The article type $1 has been deleted.", "Tip članka $1 je obrisan.");
regGS("The article type $1 has been added.", "Tip članka $1 je dodat.");
regGS("Article type field $1 created", "Polje $1 za tip članka kreirano");
regGS("Article type field $1 deleted", "Polje $1 tipa članka je obrisano");
regGS("Language $1 added", "Dodat je jezik $1");
regGS("Language $1 deleted", "Jezik $1 je obrisan");
regGS("Language $1 modified", "Jezik $1 je modifikovan");
regGS("Country $1 added", "Država $1 je dodata");
regGS("Country $1 deleted", "Država $1 je obrisana");
regGS("Country name $1 changed", "Ime države $1 je promenjeno");
regGS("The user account $1 has been deleted.", "Korisnički nalog $1 je obrisan");
regGS("Password changed for $1", "Promenjena je lozinka za $1");
regGS("User account $1 created", "Kreiran je korisnički nalog za $1");
regGS("Template $1 uploaded", "Šablon $1 je aploudovan");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sh/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "IP grupa adresa $1 je obrisana.");
regGS("IP Group $1 added for user $2", "IP grupa $1 dodata za korisnika $2");
regGS("User permissions for $1 changed", "Korisnička prava za $1 su promenjena");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Rubrika $1 obrisana. (Izdanje: $2, publikacija: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Rubrika $1 dodata. (Izdanje: $2, publikacija: $3)");
regGS("Issue $1 changed status to $2", "Izdanju $1 promenjen status u $2 ");
regGS("User type $1 deleted", "Tip korisnika $1 je obrisan");
regGS("User type $1 added", "Tip korisnika $1 je dodat");
regGS("Topic $1 added to article", "Tema $1 je dodata tekstu");
regGS("Last", "Poslednji");
regGS("First", "Prvi");
regGS("Changed image properties of $1", "Promeni osobine slike $1");
regGS("Article topic $1 deleted", "Tema teksta $1 je obrisana");
regGS("Article #$1 \"$2\" ($3) created.", "Tekst #$1 \"$2\" ($3) je kreiran.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Tekst #$1 \"$2\" ($3) je preveden u \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Tekst #$1 \"$2\" ($3) je prekopiran u #$3.");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Status teksta  #$1: \"$2\" je promenjen iz $3 to $4.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Tekst #$1: \"$2\" ($3) je obrisan.");
regGS("Text", "Tekst");
regGS("Article body", "Složen tekst");
regGS("The default subscription time for $1 has been added.", "Novi period pretplate za $1 dodat.");
regGS("Image $1 linked to article $2", "Slika $1 je povezana sa tekstom $2");
regGS("Image $1 unlinked from $2", "Veza slike $1 je uklonjena sa $2");
regGS("The image $1 has been added.", "Slika $1 je dodata");
regGS("Image $1 deleted", "Slika $1 je obrisana");
regGS("Publication $1 changed", "Publikacija $1 promenjena");
regGS("Publication $1 deleted", "Publikacija $1 je obrisana");
regGS("Publication $1 added", "Publikacija $1 je dodata");
regGS("Issue $1 from publication $2 deleted", "Izdanje $1 iz publikacije $2 je obrisano");
regGS("Issue $1 added in publication $2", "Izdanje $1 dodato u publikaciju $2");
regGS("The article type $1 has been deleted.", "Tip teksta $1 je obrisan.");
regGS("The article type $1 has been added.", "Tip teksta $1 je dodat.");
regGS("Article type field $1 created", "Polje $1 za tip teksta kreirano");
regGS("Article type field $1 deleted", "Polje $1 tipa teksta je obrisano");
regGS("Language $1 added", "Dodat je jezik $1");
regGS("Language $1 deleted", "Jezik $1 je obrisan");
regGS("Language $1 modified", "Jezik $1 je modifikovan");
regGS("Country $1 added", "Država $1 je dodata");
regGS("Country $1 deleted", "Država $1 je obrisana");
regGS("Country name $1 changed", "Ime države $1 je promenjeno");
regGS("The user account $1 has been deleted.", "Korisnički nalog $1 je obrisan");
regGS("Password changed for $1", "Promenjena je lozinka za $1");
regGS("User account $1 created", "Kreiran je korisnički nalog za $1");
regGS("Template $1 uploaded", "Šablon $1 je aploudovan");
?>
